@@ -73,7 +73,7 @@ summary.cdm_reference <- function(object, ...) {
         "min" = min(.data$observation_period_start_date, na.rm = TRUE)
       ) |>
       dplyr::collect() |>
-      dplyr::mutate(dplyr::across(dplyr::everything(), as.character))
+      dplyr::mutate(dplyr::across(dplyr::everything(), \(x) as.character(x)))
   } else {
     observation_period_info <- dplyr::tibble(
       "count" = "0", "max" = NA_character_, "min" = NA_character_
@@ -91,7 +91,9 @@ summary.cdm_reference <- function(object, ...) {
   # cdm source data
   vocab_version <- getVocabularyVersion(object)
   if ("cdm_source" %in% names(object) &&
-      object[["cdm_source"]] |> dplyr::tally() |> dplyr::pull("n") == 1) {
+    object[["cdm_source"]] |>
+      dplyr::tally() |>
+      dplyr::pull("n") == 1) {
     cdmSourceSummary <- object[["cdm_source"]] |>
       dplyr::collect() |>
       dplyr::select(dplyr::any_of(c(
@@ -136,7 +138,7 @@ summary.cdm_reference <- function(object, ...) {
       "cdm_release_date", "cdm_description", "cdm_documentation_reference"
     ))) |>
     dplyr::mutate("cdm_source_type" = sourceType(object)) |>
-    dplyr::mutate(dplyr::across(dplyr::everything(), as.character)) |>
+    dplyr::mutate(dplyr::across(dplyr::everything(), \(x) as.character(x))) |>
     tidyr::pivot_longer(
       cols = dplyr::everything(), names_to = "variable",
       values_to = "estimate_value"
@@ -256,7 +258,7 @@ summary.cohort_table <- function(object, ...) {
       by = "cohort_definition_id"
     ) |>
     dplyr::rename("result_id" = "cohort_definition_id") |>
-    dplyr::mutate(dplyr::across(!"result_id", as.character)) |>
+    dplyr::mutate(dplyr::across(!"result_id", \(x) as.character(x))) |>
     tidyr::pivot_longer(
       cols = !c("group_level", "result_id"),
       names_to = "variable_name",
@@ -289,7 +291,7 @@ summary.cohort_table <- function(object, ...) {
       by = "cohort_definition_id"
     ) |>
     dplyr::rename("result_id" = "cohort_definition_id") |>
-    dplyr::mutate(dplyr::across(!"result_id", as.character)) |>
+    dplyr::mutate(dplyr::across(!"result_id", \(x) as.character(x))) |>
     tidyr::pivot_longer(
       cols = c(
         "number_records", "number_subjects", "excluded_records",
@@ -344,7 +346,7 @@ addPkgDetails <- function(res) {
 #' person <- tibble(
 #'   person_id = 1, gender_concept_id = 0, year_of_birth = 1990,
 #'   race_concept_id = 0, ethnicity_concept_id = 0
-#'  )
+#' )
 #' observation_period <- tibble(
 #'   observation_period_id = 1, person_id = 1,
 #'   observation_period_start_date = as.Date("2000-01-01"),
@@ -364,7 +366,9 @@ summary.summarised_result <- function(object, ...) {
   cdms <- object$cdm_name |> unique()
   cdms <- cdms[!is.na(cdms)]
   ids <- object$result_id |> unique()
-  set <- object |> settings() |> colnames()
+  set <- object |>
+    settings() |>
+    colnames()
   set <- set[set != "result_id"]
   cli::cli_inform(
     "A summarised_result object with {nrow(object)} rows, {length(ids)}
