@@ -21,5 +21,6 @@ test_that("readSourceTable", {
     cohortTables = list("cohort1" = cohort)
   )
 
-  expect_error(readSourceTable(cdm = cdm, name = "my_cohort"))
+  expect_warning(cdm2 <- readSourceTable(cdm = cdm, name = "my_cohort"))
+  expect_identical(cdm, cdm2)
 })
